==> focus-trap-react-2.1.1.tgz: package/index.js <==
var React = require('react');
var focusTrap = require('focus-trap');

var PropTypes = React.PropTypes;
var checkedProps = {
  onDeactivate: PropTypes.func.isRequired,
  escapeDeactivates: PropTypes.bool,
  clickOutsideDeactivates: PropTypes.bool,
  active: PropTypes.bool,
  initialFocus: PropTypes.string,
  tag: PropTypes.string,
};

var FocusTrap = React.createClass({
  propTypes: checkedProps,

  getDefaultProps: function() {
    return {
      active: true,
      tag: 'div',
    };
  },

  componentDidMount: function() {
    if (this.props.active) {
      this.activateTrap();
    }
  },

  componentDidUpdate: function(prevProps) {
    if (prevProps.active && !this.props.active) {
      focusTrap.deactivate();
    } else if (!prevProps.active && this.props.active) {
      this.activateTrap();
    }
  },

  componentWillUnmount: function() {
    focusTrap.deactivate();
  },

  activateTrap: function() {
    if (!this.node) return;
    focusTrap.activate(this.node, {
      onDeactivate: this.props.onDeactivate,
      initialFocus: this.props.initialFocus,
      escapeDeactivates: this.props.escapeDeactivates,
      clickOutsideDeactivates: this.props.clickOutsideDeactivates,
    });
  },

  render: function() {
    var props = this.props;

    var elementProps = {
      ref: function(el) { this.node = el; }.bind(this),
    };

    // This will get id, className, style, etc. -- arbitrary element props
    for (var prop in props) {
      if (!props.hasOwnProperty(prop)) continue;
      if (checkedProps[prop]) continue;
      elementProps[prop] = props[prop];
    }

    return React.createElement(this.props.tag, elementProps, this.props.children);
  },
});

module.exports = FocusTrap;

==> focus-trap-react-3.0.1.tgz: package/index.js <==
var React = require('react');
var createFocusTrap = require('focus-trap');

var PropTypes = React.PropTypes;
var checkedProps = {
  active: PropTypes.bool,
  paused: PropTypes.bool,
  tag: PropTypes.string,
  focusTrapOptions: PropTypes.object,
};

var FocusTrap = React.createClass({
  propTypes: checkedProps,

  getDefaultProps: function() {
    return {
      active: true,
      tag: 'div',
      paused: false,
    };
  },

  componentDidMount: function() {
    this.focusTrap = createFocusTrap(this.node, this.props.focusTrapOptions);
    if (this.props.active) {
      this.focusTrap.activate();
    }
    if (this.props.paused) {
      this.focusTrap.pause();
    }
  },

  componentDidUpdate: function(prevProps) {
    if (prevProps.active && !this.props.active) {
      this.focusTrap.deactivate();
    } else if (!prevProps.active && this.props.active) {
      this.focusTrap.activate();
    }

    if (prevProps.paused && !this.props.paused) {
      this.focusTrap.unpause();
    } else if (!prevProps.paused && this.props.paused) {
      this.focusTrap.pause();
    }
  },

  componentWillUnmount: function() {
    this.focusTrap.deactivate();
  },

  render: function() {
    var props = this.props;

    var elementProps = {
      ref: function(el) { this.node = el; }.bind(this),
    };

    // This will get id, className, style, etc. -- arbitrary element props
    for (var prop in props) {
      if (!props.hasOwnProperty(prop)) continue;
      if (checkedProps[prop]) continue;
      elementProps[prop] = props[prop];
    }

    return React.createElement(this.props.tag, elementProps, this.props.children);
  },
});

module.exports = FocusTrap;
